package org.RI.P1;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;

import org.apache.tika.exception.TikaException;
import org.apache.tika.language.detect.LanguageDetector;
import org.apache.tika.langdetect.OptimaizeLangDetector;
import org.apache.tika.language.detect.LanguageResult;
import org.apache.tika.metadata.*;
import org.apache.tika.parser.*;
import org.apache.tika.sax.BodyContentHandler;
import org.apache.tika.sax.LinkContentHandler;
import org.apache.tika.sax.TeeContentHandler;
import org.apache.tika.sax.ToHTMLContentHandler;
import org.apache.tika.parser.html.HtmlParser;
import org.xml.sax.SAXException;

public class FileData {
    private File file;
    private String filename;
    private String type;
    private String encoding;
    private LanguageResult language;
    private InputStream inputStream;
    private Metadata metadata;
    private BodyContentHandler contentHandler;
    private ParseContext parseContext;
    private AutoDetectParser parser;
    private LanguageDetector langIdentifier;
    private LinkContentHandler linkHandler;
    private TeeContentHandler teeHandler;
    private ToHTMLContentHandler toHTMLhandler;

    FileData() {
    }

    FileData(File file) throws IOException, TikaException, SAXException {
        this.file = file;
        inputStream = new FileInputStream(file);
        metadata = new Metadata();
        parser = new AutoDetectParser();
        contentHandler = new BodyContentHandler(-1);
        parseContext = new ParseContext();
        langIdentifier = new OptimaizeLangDetector().loadModels();
        linkHandler = new LinkContentHandler();
        toHTMLhandler = new ToHTMLContentHandler();
        setMetadata();
    }

    private void setMetadata() throws IOException, TikaException, SAXException {
        parser.parse(inputStream, contentHandler, metadata, parseContext);
        filename = metadata.get(TikaCoreProperties.TITLE);
        type = metadata.get(Metadata.CONTENT_TYPE);
        encoding = metadata.get(Metadata.CONTENT_ENCODING);
        language = langIdentifier.detect(contentHandler.toString());
    }

    void getLinks() throws IOException, TikaException, SAXException {
        HtmlParser htmlParser = new HtmlParser();
        inputStream = new FileInputStream(file);
        teeHandler = new TeeContentHandler(linkHandler, contentHandler, toHTMLhandler);
        htmlParser.parse(inputStream, teeHandler, metadata, parseContext);
        System.out.println("Filename: " + filename);
        System.out.println("Links: " + linkHandler.getLinks());
    }

    @Override
    public String toString() {
        return "Filename: " + filename + "\n" + "Type: " + type + "\n" + "Encoding: " + encoding + "\n" + "Language: "
                + language.getLanguage() + "\n";
    }

}
